package com.futu.course.es.Service;

import com.futu.course.course.service.impl.CourseServiceImpl;
import org.elasticsearch.action.search.SearchRequest;
import org.elasticsearch.action.search.SearchResponse;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.index.query.BoolQueryBuilder;
import org.elasticsearch.index.query.QueryBuilders;
import org.elasticsearch.search.SearchHit;
import org.elasticsearch.search.builder.SearchSourceBuilder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Map;

/**
 * @author "杨旭朋"
 * @ClassName: ESCourseService
 * @date 2025年05月06日 15:54
 */
@Service
public class ESCourseService {
    @Autowired
    RestHighLevelClient client;
    @Autowired
    CourseServiceImpl courseService;
    /**
     * @title: search
     * @desc:  ES搜索指引
     * @params ( String name)
     * @return: ArrayList<String>
     * @author: 杨旭朋
     * @date: 2025/5/6 16:29
     */
    public ArrayList<String> search(String name) throws IOException {
        // 创建搜索请求
        SearchRequest searchRequest = new SearchRequest("course");
        // 创建搜索容器
        SearchSourceBuilder searchSourceBuilder = new SearchSourceBuilder();
        // 创建布尔查询器
        BoolQueryBuilder boolQueryBuilder = QueryBuilders.boolQuery()
                // 创建条件，在条件中添加 match 查询，使用 ik 分词器
                .must(QueryBuilders.matchQuery("name", name));
        // 设置查询的最大条数
        searchSourceBuilder.size(10);
        // 将搜索容器添加搜索条件
        searchSourceBuilder.query(boolQueryBuilder);
        // 添加数据为搜索容器
        searchRequest.source(searchSourceBuilder);
        // 执行请求，并获取响应
        SearchResponse search = client.search(searchRequest, RequestOptions.DEFAULT);
        System.out.println(searchRequest);
        // 返回搜索结果
        SearchHit[] hits = search.getHits().getHits();
        ArrayList<String> list = new ArrayList<>();
        for (SearchHit hit : hits) {
            Map<String, Object> sourceAsMap = hit.getSourceAsMap();
            list.add((String) sourceAsMap.get("name"));
        }
        return list;
    }
    /**
     * @title: MysqlInterES
     * @desc:  将mysql中的数据与mysql进行同步
     * @params ()
     * @return: Result
     * @author: 杨旭朋
     * @date: 2025/5/6 16:50
     */
    public void MysqlInterES(){

    }
}